==> react-native-components-8.0.5-alpha.0.tgz: package/core/Header/HeaderBackgroundImage.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Animated, Dimensions, StyleSheet } from 'react-native';
import { useSearch } from './contexts/SearchContextProvider';
import { useHeaderHeight } from './contexts/HeaderHeightContextProvider';
import { useHeaderDimensions } from '../__hooks__/useHeaderDimensions';
const defaultStyles = (deviceWidth) => StyleSheet.create({
    root: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        resizeMode: 'cover',
        width: deviceWidth,
    },
});
/**
 * HeaderBackgroundImage component
 *
 * The HeaderBackgroundImage is a helper component for organizing the contents in the Header. It is
 * used for displaying the background image and blending it with the background color.
 */
export const HeaderBackgroundImage = (props) => {
    const { backgroundImage, style } = props, otherImageProps = __rest(props, ["backgroundImage", "style"]);
    const { searching } = useSearch();
    const { headerHeight } = useHeaderHeight();
    const { width } = Dimensions.get('screen');
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    if (backgroundImage && !searching) {
        return (React.createElement(Animated.Image, Object.assign({ testID: 'header-background-image', resizeMethod: 'resize' }, otherImageProps, { source: backgroundImage, style: [
                defaultStyles(width).root,
                style,
                {
                    height: headerHeight,
                    opacity: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [0.2, 0.3],
                    }),
                },
            ] })));
    }
    return null;
};

==> react-native-components-9.0.0-alpha.0.tgz: package/core/Header/HeaderBackgroundImage.js <==
import React from 'react';
import { Animated, Dimensions, StyleSheet } from 'react-native';
import { useSearch } from './contexts/SearchContextProvider.js';
import { useHeaderHeight } from './contexts/HeaderHeightContextProvider.js';
import { useHeaderDimensions } from '../__hooks__/useHeaderDimensions.js';
const defaultStyles = (deviceWidth) => StyleSheet.create({
    root: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        resizeMode: 'cover',
        width: deviceWidth,
    },
});
/**
 * HeaderBackgroundImage component
 *
 * The HeaderBackgroundImage is a helper component for organizing the contents in the Header. It is
 * used for displaying the background image and blending it with the background color.
 */
export const HeaderBackgroundImage = (props) => {
    const { backgroundImage, style, ...otherImageProps } = props;
    const { searching } = useSearch();
    const { headerHeight } = useHeaderHeight();
    const { width } = Dimensions.get('screen');
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    if (backgroundImage && !searching) {
        return (React.createElement(Animated.Image, { testID: 'header-background-image', resizeMethod: 'resize', ...otherImageProps, source: backgroundImage, style: [
                defaultStyles(width).root,
                style,
                {
                    height: headerHeight,
                    opacity: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [0.2, 0.3],
                    }),
                },
            ] }));
    }
    return null;
};
